@@ -1,4 +1,4 @@
-# Copyrights 2009-2015 by [Mark Overmeer].
+# Copyrights 2009-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP12::Server;
 use vars '$VERSION';
-$VERSION = '3.04';
+$VERSION = '3.05';
 
 use base 'XML::Compile::SOAP12', 'XML::Compile::SOAP::Server';
 
@@ -40,7 +40,7 @@ sub makeError(@)
        || { Text    => [ { lang => 'en', _ => $args{faultstring} } ] };
 
     info "Fault: $error{Reason}{Text}[0]{_}";
-    $self->faultWriter->(Fault => \%args);
+    $self->faultWriter->(Fault => \%error);
 }
 
 sub faultValidationFailed($$)
